@@ -5,7 +5,7 @@ from pathlib import Path
 from subprocess import PIPE, Popen, check_call, check_output
 from typing import List, Optional, TextIO, Union
 
-from fasta_reader import FASTAItem, FASTAParser
+from fasta_reader import FASTAItem, read_fasta
 
 from ._misc import make_path
 from .bin import hmmemit, hmmfetch, hmmpress, hmmscan, hmmsearch
@@ -169,7 +169,10 @@ class HMMER:
         return self._indexed == State.YES
 
     def fetch_profile(self, key: str) -> str:
-        return check_output([str(hmmfetch), str(self._profile), key], text=True)
+        output = check_output([str(hmmfetch), str(self._profile), key], text=True)
+        if output[-1] == "\n":
+            output = output[:-1]
+        return output
 
     def press(self):
         check_call([hmmpress, self._profile])
@@ -182,7 +185,10 @@ class HMMER:
                     file.write(f"{acc}\n")
 
             cmd = f"{hmmfetch} -f {self._profile} {keyfile}"
-            return check_output(cmd, shell=True, text=True)
+            output = check_output(cmd, shell=True, text=True)
+            if output[-1] == "\n":
+                output = output[:-1]
+            return output
 
     @property
     def is_pressed(self) -> bool:
@@ -202,7 +208,7 @@ class HMMER:
         flags = " ".join(options)
         cmd = f"{hmmfetch} {self._profile} {hmmkey} | {hmmemit} {flags} -"
         output = check_output(cmd, shell=True, text=True)
-        return FASTAParser(StringIO(output)).read_items()
+        return read_fasta(StringIO(output)).read_items()
 
     def scan(
         self,
